# python UECP implementation

[![PyPI](https://img.shields.io/pypi/v/uecp)](https://pypi.org/project/uecp/)
[![Tests](https://github.com/chrko/python-uecp/actions/workflows/tests.yml/badge.svg)](https://github.com/chrko/python-uecp/actions/workflows/tests.yml)
[![codecov](https://codecov.io/github/chrko/python-uecp/graph/badge.svg?token=3QWRMTOESE)](https://codecov.io/github/chrko/python-uecp)

This library aims to support UECP version 6.02. It will start with basic commands required to support our needs.
